@@ -64,7 +64,7 @@ impl CacheTargetParams {
 }
 
 impl fmt::Display for CacheTargetParams {
-    fn fmt(&self, f: &mut fmt::Formatter) -> fmt::Result {
+    fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
         write!(f, "{} {}", CACHE_TARGET_NAME, self.param_str())
     }
 }
@@ -191,7 +191,7 @@ impl CacheDevTargetTable {
 }
 
 impl fmt::Display for CacheDevTargetTable {
-    fn fmt(&self, f: &mut fmt::Formatter) -> fmt::Result {
+    fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
         let table = &self.table;
         writeln!(f, "{} {} {}", *table.start, *table.length, table.params)
     }
